@@ -278,6 +278,83 @@ class DriveTemplateForm(NetBoxModelForm):
         return template_configuration
 
 
+class PartitionTemplateForm(NetBoxModelForm):
+    size = FloatField(
+        label="Size (GB)",
+        help_text="The size of the logical volume e.g. 25",
+        validators=[MinValueValidator(0.1)],
+    )
+    drive = DynamicModelChoiceField(
+        queryset=Drive.objects.all(),
+        help_text="The Cluster Type of the drive",
+    )
+    platform = DynamicModelChoiceField(
+        queryset=Platform.objects.all(),
+        help_text="Mapping between Volume and platform e.g. Rocky Linux 8",
+    )
+    path = CharField(
+        label="Path",
+        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    )
+    fs_type = DynamicModelChoiceField(
+        queryset=Filesystem.objects.all(),
+        label="Filesystem Name",
+        widget=APISelect(
+            attrs={"data-url": reverse_lazy("plugins-api:netbox_storage-api:filesystem-list")}
+        ),
+        help_text="The Filesystem of the Volume e.g. ext4",
+    )
+    fs_options = CharField(
+        label="FS Options",
+        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    )
+    label = CharField(
+        label="Partition Label",
+        help_text="The mounted path of the volume e.g. /var/lib/docker",
+    )
+
+    fieldsets = (
+        (
+            "Select drive",
+            (
+                "drive",
+                "platform",
+            ),
+        ),
+        (
+            "Select drive",
+            (
+                "path",
+                "size",
+                "fs_type",
+                "fs_options",
+                "label",
+            ),
+        ),
+    )
+
+# /boot/efi --fstype="efi" --ondisk=sda --size=126 --fsoptions="umask=0077,shortname=winnt" --label=boot_efi
+    class Meta:
+        model = Partition
+        fields = [
+            "platform",
+        ]
+
+    def save(self, *args, **kwargs):
+        drive = Drive.objects.filter(id=1)
+        partition = Partition.objects.create(drive=drive, )
+        self.instance.drive = drive
+        template_configuration = super().save(*args, **kwargs)
+
+        print(f"{self.cleaned_data['size']}")
+
+        print("Instances")
+        print(drive)
+        print(template_configuration)
+
+        return template_configuration
+
+
 class VolumeSimpleForm(NetBoxModelForm):
     """Form for creating a new Drive object."""
     # ct = ClusterType.objects.filter(name="Storage").values_list('id', flat=True)[0]
