@@ -45,11 +45,7 @@ class Migration(migrations.Migration):
                     ),
                 ),
                 ("id", models.BigAutoField(primary_key=True, serialize=False)),
-                ("drive",
-                 models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="drive_device",
-                                   to="netbox_storage.drive")),
                 ("device", models.CharField(max_length=255)),
-                ("size", models.FloatField()),
                 ("type", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
             ],
@@ -71,7 +67,8 @@ class Migration(migrations.Migration):
                 ("drive",
                  models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="drive_partition",
                                    to="netbox_storage.drive")),
-                ("device", models.CharField(max_length=255)),
+                ("device", models.ForeignKey(on_delete=models.deletion.PROTECT, related_name="device_partition",
+                                             to='netbox_storage.linuxdevice')),
                 ("size", models.FloatField()),
                 ("type", models.CharField(max_length=255)),
                 ("description", models.CharField(max_length=255)),
