@@ -69,17 +69,9 @@ class Drive(NetBoxModel):
 
 
 class LinuxDevice(NetBoxModel):
-    drive = models.ForeignKey(
-        Drive,
-        on_delete=models.CASCADE,
-        related_name='drive_device',
-    )
     device = models.CharField(
         max_length=255,
     )
-    size = models.FloatField(
-        verbose_name="Size (GB)"
-    )
     type = models.CharField(
         max_length=255,
     )
@@ -88,11 +80,7 @@ class LinuxDevice(NetBoxModel):
         blank=True,
     )
 
-    clone_fields = ["drive", "device", "size", "type", "description"]
-
-    prerequisite_models = (
-        'netbox_storage.Drive',
-    )
+    clone_fields = ["device", "type", "description"]
 
     class Meta:
         ordering = ["size"]
@@ -107,8 +95,10 @@ class Partition(NetBoxModel):
         on_delete=models.CASCADE,
         related_name='drive_partition',
     )
-    device = models.CharField(
-        max_length=255,
+    device = models.ForeignKey(
+        LinuxDevice,
+        on_delete=models.CASCADE,
+        related_name='device_partition',
     )
     size = models.FloatField(
         verbose_name="Size (GB)"
