@@ -69,20 +69,20 @@ partition_menu_item = PluginMenuItem(
     ),
 )
 
-linuxvolume_menu_item = PluginMenuItem(
-    link="plugins:netbox_storage:linuxvolume_list",
-    link_text="Linux Volume",
+mounted_volume_menu_item = PluginMenuItem(
+    link="plugins:netbox_storage:mountedvolume_list",
+    link_text="Mounted Volume",
     permissions=["netbox_storage.disk_view"],
     buttons=(
         PluginMenuButton(
-            "plugins:netbox_storage:linuxvolume_add",
+            "plugins:netbox_storage:mountedvolume_add",
             "Add",
             "mdi mdi-plus-thick",
             ButtonColorChoices.GREEN,
             permissions=["netbox_storage.add_disk"],
         ),
         PluginMenuButton(
-            "plugins:netbox_storage:linuxvolume_import",
+            "plugins:netbox_storage:mountedvolume_import",
             "Import",
             "mdi mdi-upload",
             ButtonColorChoices.CYAN,
@@ -103,7 +103,7 @@ menu = PluginMenu(
         (
             "Linux Volume Configuration",
             (
-                linuxvolume_menu_item,
+                mounted_volume_menu_item,
             ),
         ),
         (
