@@ -4,11 +4,10 @@ from netbox.tables import (
     NetBoxTable,
     ToggleColumn,
 )
-from netbox_storage.models import LinuxVolume
+from netbox_storage.models import MountedVolume
 
 
-class LinuxVolumeTable(NetBoxTable):
-    """Table for displaying LinuxVolume objects."""
+class MountedVolumeTable(NetBoxTable):
 
     pk = ToggleColumn()
     fs = tables.Column(
@@ -29,7 +28,7 @@ class LinuxVolumeTable(NetBoxTable):
     )
 
     class Meta(NetBoxTable.Meta):
-        model = LinuxVolume
+        model = MountedVolume
         fields = (
             "pk",
             "partition",
