@@ -2,7 +2,7 @@ import logging
 
 from extras.plugins import PluginTemplateExtension
 from netbox_storage.models import PhysicalVolume, LogicalVolume, MountedVolume, StorageConfigurationLinuxVolume, \
-    TemplateConfigurationLinuxVolume
+    TemplateConfigurationLinuxVolume, Drive
 
 
 class RelatedDrives(PluginTemplateExtension):
@@ -43,24 +43,19 @@ class RelatedDrives(PluginTemplateExtension):
 class TemplateVolumeConfig(PluginTemplateExtension):
     model = "dcim.platform"
 
-    def right_page(self):
+    def full_width_page(self):
         obj = self.context.get("object")
 
-        lv = LogicalVolume.objects.all()
-        drives = TemplateConfigurationLinuxVolume.objects.values('drive').filter(platform=obj)
-        print("template content")
-        print(drives)
-        for d in drives:
-            print(d.size)
-            print(d.drive)
-
-
-        # storage_configuration = StorageConfigurationLinuxVolume.objects.filter(virtual_machine=obj)
+        drives_id = TemplateConfigurationLinuxVolume.objects.values('drive').filter(platform=obj)
+        print(drives_id)
+        for drive_id in drives_id:
+            print(drive_id['drive'])
 
+        drives = Drive.objects.filter(pk__in=[1, 2])
         return self.render(
             "netbox_storage/inc/template_box.html",
             extra_context={
-                "template_linux_volumes": drives,
+                "drives": drives,
             }
         )
 
