@@ -124,5 +124,6 @@ urlpatterns = [
     #
     path('template-lvm-add/', LVMAddTemplateView.as_view(), name='template_lvm_add'),
     path('template-volume-add/', AddTemplateVolumeView.as_view(), name="template_volume_add"),
-    path('template-drive-add/', AddTemplateDriveView.as_view(), name='template_drive_add')
+    path('template-drive-add/', AddTemplateDriveView.as_view(), name='template_drive_add'),
+    path('template-partition-add', AddTemplatePartitionView.as_view(), name='template_partition_add')
 ]
