@@ -1,7 +1,8 @@
 from netbox.views import generic
 
 from netbox_storage.forms import LVMSimpleForm, VolumeSimpleForm, LinuxVolumeSimpleForm
-from netbox_storage.forms.template import LinuxVolumeTemplateForm, LVMTemplateForm, DriveTemplateForm
+from netbox_storage.forms.template import LinuxVolumeTemplateForm, LVMTemplateForm, DriveTemplateForm, \
+    PartitionTemplateForm
 from netbox_storage.models import Drive, StorageConfigurationLinuxVolume, TemplateConfigurationLinuxVolume
 
 
@@ -25,3 +26,8 @@ class AddTemplateVolumeView(generic.ObjectEditView):
 class AddTemplateDriveView(generic.ObjectEditView):
     queryset = TemplateConfigurationLinuxVolume.objects.all()
     form = DriveTemplateForm
+
+
+class AddTemplatePartitionView(generic.ObjectEditView):
+    queryset = TemplateConfigurationLinuxVolume.objects.all()
+    form = PartitionTemplateForm
